Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2283)

Unified Diff: ash/shell.h

Issue 10442017: Rename GetRootWindow() -> GetPrimaryRootWindow() (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/screensaver/screensaver_view.cc ('k') | ash/shell.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/shell.h
diff --git a/ash/shell.h b/ash/shell.h
index fa8c50da33bfab38dcb252048640b8783705295c..d7929f59e2009b9662fd75f6f229872963bc029f 100644
--- a/ash/shell.h
+++ b/ash/shell.h
@@ -133,8 +133,9 @@ class ASH_EXPORT Shell {
static void DeleteInstance();
- // Gets the singleton RootWindow used by the Shell.
- static aura::RootWindow* GetRootWindow();
+ // Gets the prmiary RootWindow. The primary RootWindow is the root window
Ben Goodger (Google) 2012/05/24 21:07:57 primary
+ // that has a laucnher.
Ben Goodger (Google) 2012/05/24 21:07:57 launcher
+ static aura::RootWindow* GetPrimaryRootWindow();
internal::RootWindowLayoutManager* root_window_layout() const {
return root_window_layout_;
« no previous file with comments | « ash/screensaver/screensaver_view.cc ('k') | ash/shell.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698